DROP TABLE IF EXISTS `config`;

CREATE TABLE `config` (
  id int unsigned not null auto_increment,
  cfg_name VARCHAR(255) not null,
  cfg_value BLOB,
  created_at TIMESTAMP,
  updated_at TIMESTAMP,
  primary key(id)

) ENGINE = InnoDB DEFAULT CHARSET = utf8;