<?php

use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateConfig extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('config', function (Blueprint $table) {
            $table->increments('id')->unsigned();
            $table->string('cfg_name', 255);
            $table->timestamps();
        });

        DB::statement("ALTER TABLE config ADD `cfg_value` BLOB DEFAULT NULL AFTER `cfg_name`");
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::drop('config');
    }
}
