<?php

namespace Buckhill;

if(!function_exists(__NAMESPACE__ . '\config'))
{
    function config($key = null, $default = null)
    {
        if(is_null($key))
        {
            return Configuration::getInstance();
        }

        if(is_array($key))
        {
            return Configuration::getInstance()->setFromKey($key);
        }

        return Configuration::getInstance()->get($key, $default);
    }
}

if(!function_exists(__NAMESPACE__ . '\configCreate'))
{
    function configCreate($key = '', $value = '')
    {
        return Configuration::getInstance()->create($key, $value);
    }
}

if(!function_exists(__NAMESPACE__ . '\configUpdate'))
{
    function configUpdate($key, $value)
    {
        return Configuration::getInstance()->update($key, $value);
    }
}

if(!function_exists(__NAMESPACE__ . '\configRetrieve'))
{
    function configRetrieve($key = '')
    {
        return Configuration::getInstance()->retrieve($key);
    }
}